Learn R Programming

rheroicons (version 1.0.0)

find_icons: Find available icons

Description

You can search for icons by querying the icon set. For example, if you would like to find icons that are arrows and chevrons, then type in you query as a regexp: 'arrows|chevrons'. Alternatively, if you would like to view all icon names, leave the value for 'query' blank.

Usage

find_icons(query = ".")

Value

An array of icon names

Arguments

query

a string containing a search term

References

https://heroicons.com https://github.com/tailwindlabs/heroicons

Examples

Run this code
find_icons(query = "chevron")
find_icons(query = "chevron|arrow")
find_icons(query = "down|up|left|right")
find_icons(query = "-circle")
find_icons(query = "(-down)$")

Run the code above in your browser using DataLab