Learn R Programming

rheroicons (version 1.0.0)

launch_gallery: Icon gallery

Description

Run the gallery to view and search for icons. Click on an icon name to copy the 'R' code to the clipboard.

Usage

launch_gallery(...)

Value

A 'shiny' app containing the icon gallery

Arguments

...

additional 'shiny' options

Examples

Run this code
if (interactive()) {
  rheroicons::launch_gallery()
}

Run the code above in your browser using DataLab