powered by
Run the gallery to view and search for icons. Click on an icon name to copy the 'R' code to the clipboard.
launch_gallery(...)
A 'shiny' app containing the icon gallery
additional 'shiny' options
if (interactive()) { rheroicons::launch_gallery() }
Run the code above in your browser using DataLab